@@ -1,4 +1,4 @@
-/* Copyright 2008,2009,2010,2011,2012,2013 Rolf Eike Beer <kde@opensource.sf-tec.de>
+/* Copyright 2008,2009,2010,2011,2012,2013,2016 Rolf Eike Beer <kde@opensource.sf-tec.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -18,13 +18,15 @@
  */
 #include "kgpgitemmodel.h"
 
+#include "gpgproc.h"
 #include "kgpgsettings.h"
 #include "core/convert.h"
 #include "core/images.h"
 #include "model/kgpgitemnode.h"
 
-#include <KGlobal>
-#include <KLocale>
+#include <KLocalizedString>
+
+#include <QLocale>
 #include <QMetaObject>
 
 KGpgItemModel::KGpgItemModel(QObject *parent)
@@ -179,7 +181,7 @@ KGpgItemModel::data(const QModelIndex &index, int role) const
 		}
 	case KEYCOLUMN_EXPIR:
 		if (role == Qt::DisplayRole)
-			return KGlobal::locale()->formatDate(node->getExpiration().date(), KLocale::ShortDate);
+			return QLocale().toString(node->getExpiration().date(), QLocale::ShortFormat);
 		break;
 	case KEYCOLUMN_SIZE:
 		switch (role) {
@@ -201,7 +203,7 @@ KGpgItemModel::data(const QModelIndex &index, int role) const
 		break;
 	case KEYCOLUMN_CREAT:
 		if (role == Qt::DisplayRole)
-			return KGlobal::locale()->formatDate(node->getCreation().date(), KLocale::ShortDate);
+			return QLocale().toString(node->getCreation().date(), QLocale::ShortFormat);
 		break;
 	case KEYCOLUMN_ID:
 		switch (role) {
@@ -305,13 +307,13 @@ KGpgItemModel::delNode(KGpgNode *node)
 }
 
 void
-KGpgItemModel::changeGroup(KGpgGroupNode *node, const QList<KGpgNode *> &keys)
+KGpgItemModel::changeGroup(KGpgGroupNode *node, const KGpgNode::List &keys)
 {
 	const QModelIndex gIndex = nodeIndex(node);
 	for (int i = node->getChildCount() - 1; i >= 0; i--) {
 		bool found = false;
 
-		foreach (const KGpgNode *nd, keys) {
+		for (const KGpgNode *nd : keys) {
 			found = (node->getChild(i)->getId() == nd->getId());
 			if (found)
 				break;
@@ -329,7 +331,7 @@ KGpgItemModel::changeGroup(KGpgGroupNode *node, const QList<KGpgNode *> &keys)
 	for (int i = 0; i < keys.count(); i++) {
 		bool found = false;
 
-		foreach (const KGpgNode *nd, node->getChildren()) {
+		for (const KGpgNode *nd : node->getChildren()) {
 			found = (nd->getId() == keys.at(i)->getId());
 			if (found)
 				break;
@@ -417,47 +419,20 @@ KGpgItemModel::nodeIndex(KGpgNode *node, const int column)
 	return QModelIndex();
 }
 
-void
-KGpgItemModel::refreshKey(KGpgKeyNode *nd)
+static QStringList
+readGroups()
 {
-	KGpgKeyNode::List nodes;
-
-	nodes.append(nd);
-
-	refreshKeyIds(nodes);
-}
-
-void
-KGpgItemModel::refreshKey(const QString &id)
-{
-	refreshKeyIds(QStringList(id));
-}
-
-void
-KGpgItemModel::refreshKeys(KGpgKeyNode::List keys)
-{
-	refreshKeyIds(keys);
+	return GPGProc::getGgpParsedConfig(KGpgSettings::gpgBinaryPath(), "group");
 }
 
 void
 KGpgItemModel::refreshKeys(const QStringList &ids)
 {
-	refreshKeyIds(ids);
-}
-
-void
-KGpgItemModel::refreshKeyIds(const QStringList &ids)
-{
-	beginResetModel();
 	if (ids.isEmpty()) {
-		for (int i = m_root->getChildCount() - 1; i >= 0; i--) {
-			KGpgNode *nd = m_root->getChild(i);
-			if (nd->getType() == ITYPE_GROUP)
-				continue;
-			delete nd;
-		}
-		m_root->addKeys();
+		refreshAllKeys();
 	} else {
+		beginResetModel();
+
 		QStringList::ConstIterator it = ids.constBegin();
 		const QStringList::ConstIterator itEnd = ids.constEnd();
 
@@ -476,16 +451,30 @@ KGpgItemModel::refreshKeyIds(const QStringList &ids)
 			m_root->refreshKeys(refreshNodes);
 		if (!addIds.isEmpty())
 			m_root->addKeys(addIds);
-	}
 
+		endResetModel();
+	}
+}
+
+void
+KGpgItemModel::refreshKeys(KGpgKeyNode::List keys)
+{
+	beginResetModel();
+	m_root->refreshKeys(keys);
 	endResetModel();
 }
 
 void
-KGpgItemModel::refreshKeyIds(KGpgKeyNode::List &nodes)
+KGpgItemModel::refreshAllKeys()
 {
 	beginResetModel();
-	m_root->refreshKeys(nodes);
+
+	for (int i = m_root->getChildCount() - 1; i >= 0; i--)
+		delete m_root->getChild(i);
+	m_root->addKeys();
+
+	m_root->addGroups(readGroups());
+
 	endResetModel();
 }
 
@@ -502,7 +491,7 @@ KGpgItemModel::refreshGroups()
 		endRemoveRows();
 	}
 
-	const QStringList groups = KGpgGroupNode::readGroups();
+	const QStringList groups = readGroups();
 
 	if (groups.isEmpty())
 		return;
@@ -522,7 +511,8 @@ KGpgItemModel::isDefaultKey(const KGpgNode *node) const
 void
 KGpgItemModel::invalidateIndexes(KGpgNode *nd)
 {
-	foreach (const QModelIndex &idx, persistentIndexList()) {
+	const auto indexList = persistentIndexList();
+	for (const QModelIndex &idx : indexList) {
 		KGpgNode *n = nodeForIndex(idx);
 
 		if (n != nd)
