@@ -50,7 +50,7 @@ public:
 
 	/**
 	 * @brief set the ids to delete
-	 * @param signids fingerprints of the signatures to delete
+	 * @param keyids fingerprints of the signatures to delete
 	 *
 	 * This will replace all previously set signature ids.
 	 */
@@ -69,8 +69,8 @@ public:
 	KGpgSignNode::List getSignIds(void) const;
 
 protected:
-	virtual bool nextLine(const QString &line) Q_DECL_OVERRIDE;
-	virtual ts_boolanswer boolQuestion(const QString &line) Q_DECL_OVERRIDE;
+	bool nextLine(const QString &line) Q_DECL_OVERRIDE;
+	ts_boolanswer boolQuestion(const QString &line) Q_DECL_OVERRIDE;
 
 private:
 	KGpgSignNode::List m_signids;	///< the list of ids to delete
